@@ -3,7 +3,7 @@ import os
 
 from mopidy import config, ext
 
-__version__ = "0.2.0"
+__version__ = "1.1.1"
 
 logger = logging.getLogger(__name__)
 
@@ -20,10 +20,12 @@ class Extension(ext.Extension):
 
     def get_config_schema(self):
         schema = super(Extension, self).get_config_schema()
-        schema["art_url_as_comment"] = config.Boolean(optional=True)
         schema["discover_pages"] = config.Integer(optional=True)
+        schema["collection_items"] = config.Integer(optional=True)
         schema["discover_genres"] = config.List(optional=True)
         schema["discover_tags"] = config.List(optional=True)
+        schema["image_sizes"] = config.List(optional=True)
+        schema["identity"] = config.String(optional=True)
         return schema
 
     def get_command(self):
